"""A package to log broadband speed test results"""
import datetime
import logging
import sys

import click
import daiquiri
import speedtest

__version__ = "0.0.6"


@click.command()
@click.argument("directory", type=click.Path(), default=".")
def main(directory):
    daiquiri.setup(
        level=logging.INFO,
        outputs=[
            daiquiri.output.TimedRotatingFile(
                filename="speedtest.log",
                directory=directory,
                level=logging.INFO,
                interval=datetime.timedelta(weeks=1),
                formatter=daiquiri.formatter.ColorFormatter(fmt="%(message)s"),
            )
        ],
    )
    logger = daiquiri.getLogger(__name__)
    servers = []

    try:
        s = speedtest.Speedtest()
        s.get_servers(servers)
        s.get_best_server()
        s.download()
        s.upload(pre_allocate=False)
        message = s.results.csv()
    except speedtest.ConfigRetrievalError:
        message = f",,,{datetime.datetime.utcnow().isoformat()}Z,0,00,,"

    logger.info(message)



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['click', 'daiquiri', 'speedtest-cli']

entry_points = \
{'console_scripts': ['speedtest-logger = speedtest_logger:main']}

setup(name='speedtest_logger',
      version='0.0.6',
      description='A package to log broadband speed test results',
      author='Owen Campbell',
      author_email='owen.campbell@tanti.org.uk',
      url='http://owencampbell.me.uk',
      py_modules=['speedtest_logger'],
      install_requires=install_requires,
      entry_points=entry_points,
     )
